function [Result1 , Result2] = makeStatesCover(homeMarking , subtractTransitions,...
    addTransitions,excludeList,coverType)
% takes five inputs, produces two outputs. Result1 should be the struct list. Result2 should be a numerical value to represent how much space the largest state needs
% input 1 is a list of numbers representing the number of tokens in each
% marking, in the first state. the index number of the value will be
% considered the place name.
% input 2 is a matrix where each row represents the tokens removed from
% each place by a trasition. Contains only negative values or 0
% input 3 is a matrix where each row represents the tokens added to
% each place by a trasition. Contains only positive values or 0
% input 4 is a list of index numbers for transitions to ignore when making
% new states. used in continueFromSelectedMarking
% input 5 is a string for a switch statement to select the type of coverability algorithm to use (coverability or coverability_extra)
% makes use of calTransWithCoverCheck.m, DecideType.m,
% findActiveTransitions.m and calculateTransition.m
tmp2=size(subtractTransitions);
transitionMaxSub=[];
for i=1:tmp2(2)
    transitionMaxSub=[transitionMaxSub ( max(  abs(subtractTransitions(:, i))  ) +1 )];
end

homeMarkingStringArray=[];
for i = 1:length(homeMarking)
    if homeMarking(i) < inf
        homeMarkingStringArray=[homeMarkingStringArray string(homeMarking(i))];
    else
        homeMarkingStringArray=[homeMarkingStringArray string('W')];
    end
    
end

States = []; % empty struct array fill with sis elements during run
maxSpaceUsed=0;
%first state
home.parent_marking = NaN;
home.transToThis=NaN;
home.parent_ID = NaN;
home.ID = 1; % should be the same as array index of the struct
home.depth = 1; % use for graphic coordinates
home.marking = homeMarkingStringArray;
home.type = 'N';
home.listOfPrevMarks = [];
home.extraValues=[];
States = [States home]; % add to array
id=1;
activeTransitions = findActiveTransitions(homeMarkingStringArray, subtractTransitions,excludeList);
maxSpaceUsed = maxStateSpaceUsed(homeMarkingStringArray, maxSpaceUsed);
queueStructs = [];

for i = 1:length(activeTransitions)
    id = id+1;
    % make child and put into quene
    newSisElement.parent_marking = homeMarkingStringArray;
    newSisElement.parent_ID = 1;
    newSisElement.ID = id;
    newSisElement.transToThis = activeTransitions(i);
    newSisElement.depth = home.depth + 1 ;
    
    % calculate new marking
    
    newSisElement.listOfPrevMarks =[homeMarking];
    newSisElement.marking= calTransWithCoverCheck(homeMarking, newSisElement.parent_marking , ...
        subtractTransitions(activeTransitions(i),1:end) , addTransitions(activeTransitions(i),1:end),...
        coverType,transitionMaxSub);
    newSisElement.type = DecideType(newSisElement.marking ,States,queueStructs);
    
    
    newSisElement.extraValues=[];
    
    queueStructs=[queueStructs newSisElement];
    
end

while length(queueStructs) >0
    
    %fromQ is the SIS element popped from the queue toQ are new element
    %being made before put into the queue
    fromQ= queueStructs(1); % take element from index 1
    queueStructs(1)= []; %  remove element from index 1
    maxSpaceUsed = maxStateSpaceUsed(fromQ.marking, maxSpaceUsed);
    activeTransitions = findActiveTransitions(fromQ.marking, subtractTransitions,excludeList);
    
    if length(activeTransitions) ==0
        fromQ.type = 'E' ;% type E is a deadlock condition
    elseif fromQ.type =='D' % instead of putting duplicates in the queue place in the main list instead
        States = [States fromQ];
        continue
    end
    
    States = [States fromQ];
    
    for i = 1:length(activeTransitions)
        match = false;
        id = id+1;
        toQ.parent_marking= fromQ.marking;
        toQ.parent_ID = fromQ.ID ;
        toQ.ID = id;
        toQ.transToThis = activeTransitions(i);
        toQ.depth = States(fromQ.ID).depth + 1 ;
        toQ.extraValues=[];
        
        intMarking=[];
        sizeinput =size(fromQ.marking);
        for j=1:sizeinput(2)
            if char(fromQ.marking(j)) == 'W'
                intMarking = [intMarking inf];
            else
                intMarking = [intMarking str2num(char(fromQ.marking(j)))];
            end
        end
        
        tmp2=[fromQ.listOfPrevMarks ; intMarking];
        
        toQ.listOfPrevMarks = tmp2;
        
        toQ.marking= calTransWithCoverCheck(toQ.listOfPrevMarks, toQ.parent_marking , ...
            subtractTransitions(activeTransitions(i),1:end) , ...
            addTransitions(activeTransitions(i),1:end),coverType,transitionMaxSub);
        
        % check to see if duplicate exists, and add marks
        for j = 1:length(States)
            tmp = toQ.marking == States(j).marking;
            if all(tmp(:) > 0)
                match = true;
                tmp=[States(j).listOfPrevMarks ; toQ.listOfPrevMarks];
                tmp2=unique(tmp, 'rows');
                
                States(j).listOfPrevMarks=tmp2;
            end
        end
        for j = 1:length(queueStructs)
            tmp = toQ.marking == queueStructs(j).marking;
            if all(tmp(:) > 0)
                match = true;
                tmp=[queueStructs(j).listOfPrevMarks ; toQ.listOfPrevMarks];
                tmp2=unique(tmp, 'rows');
                %queueStructs(j).listOfPrevMarks=[queueStructs(j).listOfPrevMarks ; toQ.listOfPrevMarks];
                queueStructs(j).listOfPrevMarks=tmp2;
            end
        end
        
        if match
            toQ.type ='D' ;% duplicate
        else
            toQ.type ='N' ;% normal
        end
        queueStructs=[queueStructs toQ];
    end
    
end
Result1=States;
Result2=maxSpaceUsed;
end
