function [Result1 , Result2] = makeStatesDepthLim(homeMarking , subtractTransitions,...
    addTransitions, depthLimit,...
    excludeList,extraTransitionValues,extraInitialValues,initialHistory)
% takes eight inputs, produces two outputs. Result1 should be the struct list. Result2 should be a numerical value to represent how much space the largest state needs
% input 1 is a list of numbers representing the number of tokens in each
% marking, in the first state. the index number of the value will be
% considered the place name.
% input 2 is a matrix where each row represents the tokens removed from
% each place by a trasition. Contains only negative values or 0
% input 3 is a matrix where each row represents the tokens added to
% each place by a trasition. Contains only positive values or 0
% input 4 is a number. It is the maximum value used by this algorithm
% input 5 is a list of index numbers for transitions to ignore when making
% new states. used in continueFromSelectedMarking
% input 6 is a matrix, containing the extra costs for each transition.
% input 7  is a list of numbers with the extra values of the first state.
% input 8 is the transition history of the first state.
% this will have elements if this tree is the continuation of an already made tree.
% makes use of calculateTransition.m, DecideType.m,
% findActiveTransitions.m and calculateTransition.m

homeMarkingStringArray=[];
for i = 1:length(homeMarking)
    homeMarkingStringArray=[homeMarkingStringArray string(homeMarking(i))];
end

States = []; % empty struct array fill with sis elements during run

maxSpaceUsed=0;

%first state
home.parent_marking = NaN;
home.transToThis=NaN;
home.parent_ID = NaN;
home.ID = 1; % should be the same as array index of the struct
home.depth = 1; % use for graphic coordinates
home.marking = homeMarkingStringArray;
home.type = 'N';
if length(extraInitialValues)>0
    home.extraValues=extraInitialValues;
end
home.history=initialHistory;

maxSpaceUsed = maxStateSpaceUsed(homeMarkingStringArray, maxSpaceUsed);

States = [States home]; % add to array
id=1;
activeTransitions = findActiveTransitions(homeMarkingStringArray, subtractTransitions,excludeList);

queueStructs = []; % use for BFS search

for i = 1:length(activeTransitions)
    id = id+1;
    % make child and put into quene
    newSisElement.parent_marking = homeMarkingStringArray;
    newSisElement.parent_ID = 1;
    newSisElement.ID = id;
    newSisElement.transToThis = activeTransitions(i);
    newSisElement.depth = States(newSisElement.parent_ID).depth + 1 ;
    
    % calculate new marking
    newSisElement.marking= calculateTransition(newSisElement.parent_marking , subtractTransitions(activeTransitions(i),1:end) , addTransitions(activeTransitions(i),1:end));
    newSisElement.type = DecideType(newSisElement.marking ,States,queueStructs);
    
    if length(extraInitialValues)>0
        newSisElement.extraValues=home.extraValues+extraTransitionValues(activeTransitions(i) , :);
    end
    newSisElement.history=[initialHistory activeTransitions(i)];
    
    queueStructs=[queueStructs newSisElement];
    
end

while length(queueStructs) >0
    %fromQ is the SIS element popped from the queue toQ are new element
    %being made before put into the queue
    fromQ= queueStructs(1); % take element from index 1
    queueStructs(1)= []; %  remove element from index 1
    maxSpaceUsed = maxStateSpaceUsed(fromQ.marking, maxSpaceUsed);
    
    activeTransitions = findActiveTransitions(fromQ.marking, subtractTransitions,excludeList);
    if length(activeTransitions) ==0
        fromQ.type = 'E' ;% type E is a deadlock condition
    elseif fromQ.type =='D' % instead of putting duplicates in the queue place in the main list instead
        States = [States fromQ];
        continue
    end
    
    if (fromQ.depth + 1) > depthLimit
        States = [States fromQ];
        continue
    end
    
    States = [States fromQ];
    
    for i = 1:length(activeTransitions) % make states to put into queue
        match = false;
        id = id+1;
        toQ.parent_marking= fromQ.marking;
        toQ.parent_ID = fromQ.ID ;
        toQ.ID = id;
        toQ.transToThis = activeTransitions(i);
        
        toQ.depth = States(fromQ.ID).depth + 1 ;
        
        toQ.marking= calculateTransition(toQ.parent_marking , subtractTransitions(activeTransitions(i),1:end) , addTransitions(activeTransitions(i),1:end));
        if length(extraInitialValues)>0
            toQ.extraValues=fromQ.extraValues+extraTransitionValues(activeTransitions(i) , :);
        end
        toQ.history=[fromQ.history activeTransitions(i)]; % a history of all transitions up to this point
        
        % check to see if duplicate exists
        for j = 1:length(States)
            tmp = toQ.marking == States(j).marking;
            if all(tmp(:) > 0)
                match = true;
                break
            end
        end
        for j = 1:length(queueStructs)
            tmp = toQ.marking == queueStructs(j).marking;
            if all(tmp(:) > 0)
                match = true;
                break
            end
        end
        
        if match
            toQ.type ='D' ;% duplicate
        else
            toQ.type ='N' ;% normal
        end
        queueStructs=[queueStructs toQ];
    end
    
end

Result1=States;
Result2=maxSpaceUsed;
end
