function petNetCoverTreeGUI(homeMarking,subtractTransitions,addTransitions,...
    extraTransitionValues ,extraInitialValues,transistionNames)
% takes six inputs, Opens a GUI for making graphical coverability/reachability trees in matlab figures
% input 1 is a list of numbers representing the number of tokens in each
% marking, in the first state. the index number of the value will be
% considered the place name.
% input 2 is a matrix where each row represents the tokens removed from
% each place by a trasition. Contains only negative values or 0
% input 3 is a matrix where each row represents the tokens added to
% each place by a trasition. Contains only positive values or 0
% input 4 is a matrix, containing the extra costs for each transition.
% input 5 is a list of numbers with the extra values of the first state.
% input 6 is an array of strigs that need to have as many elements as there
% are rows in input 2 and 3. It is the names for each transition.
% makes use of drawGraphReachLimContinue.m, makeStatesCover.m, makeStatesDepthLim.m and makeStatesPlaceValLim.m

extran=extraTransitionValues; %debugging
initval=extraInitialValues; %debugging

fig = uifigure;
fig.Position =[20   350   560   420];

generationChoice='coverability'; %default algorithm choice. value changes from the radio buttons
States=[]; % states are generated by the make states button

% button group for radio buttons
bg = uibuttongroup(fig,...
    'Title','MakeStatesAlgorithms',...
    'Position', [50 270 223 129],...
    'SelectionChangedFcn',@(bg,event) bselection(bg,event));

% Create four radio buttons in the button group. The names are passed to
% the generationChoice to be used in later switch statements
r1 = uiradiobutton(bg,'Text','coverability','Position',[10 83 170 15]);
r2 = uiradiobutton(bg,'Text','coverability_extra','Position',[10 60 170 15]);
r3 = uiradiobutton(bg,'Text','reachabilityWithDepthLimit','Position',[10 38 170 15]);
r4 = uiradiobutton(bg,'Text','reachabilityWithValueLimit','Position',[10 15 170 15]);

%'Position' = [ x, y , lenght , height] x and y are distances from bottom right corner
% lenght, height goes up from base point.  x and lenght are horizontal
% distances, y and  height are vertical distances based off bottom right corner

chr = 'choose state generation method';
chr = [chr newline 'number of states: 0'];
statesInformation = uilabel(fig,'Position',[50 50 250 55],...
    'Text',chr,...
    'BackgroundColor', [0.7 0.7 0.7]);

% fields for limit parameters
DepthLimit = uieditfield(fig,'numeric',...
    'Position',[300 300 50 22] , 'Enable','off');
DepthLimitlbl = uilabel(fig,'Position',[355 295 150 22]...
    ,'Text','maxDepthLevel');
DepthLimit.Value = 2;
ValueLimit = uieditfield(fig,'numeric',...
    'Position',[300 270 50 22], 'Enable','off');
ValueLimitlbl = uilabel(fig,'Position',[355 265 100 22]...
    ,'Text','maxValue');
ValueLimit.Value = 2;

% field for excluding transitions
ExcludeList = uieditfield(fig,...
    'Position',[50 215 100 22] ,  'Enable','off');
ExcludeListbl = uilabel(fig,'Position',[160 210 100 22]...
    ,'Text','excludeList');
ExcludeList.Value = '1 2 3 4 5';
ExcludeListCbx = uicheckbox(fig , 'Position', [50 235 150 22] ,'Text','exclude transitions'...
    ,'ValueChangedFcn',@(btn,event) excludeToggle(btn,event) );

makeStatesBtn = uibutton(fig,'push',...
    'Position',[50 150 100 20],...
    'Text', 'Make States',...
    'ButtonPushedFcn', @(btn,event) makeStatesButton(btn,event) );

drawBtn = uibutton(fig,'push',...
    'Position',[320 50 100 20],...
    'Text', 'draw',...
    'Enable','off',...
    'ButtonPushedFcn', @(btn,event) drawStatesButton(btn,event) );

excleList=[]
maxSpaceUsed=10;
typeChoice=''

%------------------------- functions ---------------------
    function makeStatesButton(btn,event)
        % method for making states based on the chosen options
        excleList=[];
        
        switch generationChoice
            case 'coverability'
                
                disp('coverability')
                if ExcludeListCbx.Value == 1
                    disp('checkbox')
                    excleList=str2num(ExcludeList.Value);
                end
                coverType='normal'
                States=[];
                [makeRes1,makeRes2] =makeStatesCover(homeMarking,subtractTransitions,addTransitions,excleList,coverType);
                States=makeRes1;
                maxSpaceUsed=makeRes2;
                
            case 'coverability_extra'
                disp('coverability_extra')
                if ExcludeListCbx.Value == 1
                    disp('checkbox')
                    excleList=str2num(ExcludeList.Value);
                end
                
                coverType='extra'
                [makeRes1,makeRes2] =makeStatesCover(homeMarking,subtractTransitions,...
                    addTransitions,excleList,coverType);
                States=makeRes1;
                maxSpaceUsed=makeRes2;
                
            case 'reachabilityWithDepthLimit'
                disp('reachabilityWithDepthLimit')
                States=[];
                
                if ExcludeListCbx.Value == 1
                    disp('checkbox')
                    excleList=str2num(ExcludeList.Value);
                end
                
                depLim=DepthLimit.Value;
                initialHistory=[];
                
                [makeRes1,makeRes2]=makeStatesDepthLim(homeMarking , subtractTransitions, addTransitions, depLim,...
                    excleList,extran,initval,initialHistory);
                States=makeRes1;
                maxSpaceUsed=makeRes2;
                
            case 'reachabilityWithValueLimit'
                disp('reachabilityWithValueLimit')
                States=[]
                
                if ExcludeListCbx.Value == 1
                    disp('checkbox')
                    excleList=str2num(ExcludeList.Value);
                end
                disp(ValueLimit.Value)
                
                valLim=ValueLimit.Value;
                initialHistory=[];
                [makeRes1,makeRes2] =makeStatesPlaceValLim(homeMarking , subtractTransitions, addTransitions,...
                    valLim,excleList,extraTransitionValues,extraInitialValues,initialHistory);
                States=makeRes1;
                maxSpaceUsed=makeRes2;
            otherwise
                disp('error')
        end
        
        part = num2str(length(States));
        part = strcat('length:', part);
        part = [generationChoice newline part];
        if length(States) > 800
            part = [part newline 'warning: navigating figure can be slow'];
        end
        statesInformation.Text=part;
        
        if length(States)>0
            set(drawBtn,'Enable','on');
        end
        
    end

    function bselection(bg,event )
        % method for radio buttons, sets generationChoice value to be used elsewhere
        % activates relevant field, deactivate others.
        generationChoice=event.NewValue.Text;
        switch event.NewValue.Text
            case 'reachabilityWithDepthLimit'
                set(DepthLimit ,'Enable','on');
            case 'reachabilityWithValueLimit'
                set(ValueLimit,'Enable','on');
        end
        switch event.OldValue.Text
            case 'reachabilityWithDepthLimit'
                set(DepthLimit ,'Enable','off');
            case 'reachabilityWithValueLimit'
                set(ValueLimit,'Enable','off');
        end
    end
    
    function excludeToggle(bg,event ) 
        % method attached to toggle box. activated and deactivates field
        if  event.Value == 1
            set(ExcludeList,'Enable','on');
        elseif event.Value == 0
            set(ExcludeList,'Enable','off');
        end
    end

    function drawStatesButton(btn,event)
        limitNumber=1; 
        % only used in 'reachabilityWithDepthLimit' and 'reachabilityWithValueLimit'
        
        switch generationChoice % the only difference is between 'reachabilityWithDepthLimit' and 'reachabilityWithValueLimit'
            case 'coverability'
                drawGraphReachLimContinue(States ,subtractTransitions, addTransitions ,...
                    limitNumber,generationChoice,excleList,[] ,maxSpaceUsed,transistionNames )
            case  'coverability_extra'
                drawGraphReachLimContinue(States ,subtractTransitions, addTransitions ,...
                    limitNumber,generationChoice,excleList,[] ,maxSpaceUsed,transistionNames )
            case 'reachabilityWithDepthLimit'
                limitNumber=DepthLimit.Value;
                drawGraphReachLimContinue(States ,subtractTransitions, addTransitions ,...
                    limitNumber,generationChoice,excleList,extraTransitionValues,maxSpaceUsed,transistionNames )
            case 'reachabilityWithValueLimit'
                limitNumber=ValueLimit.Value;
                drawGraphReachLimContinue(States ,subtractTransitions, addTransitions ,...
                    limitNumber,generationChoice,excleList,extraTransitionValues,maxSpaceUsed,transistionNames )
        end
        
    end

end
